@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -75,9 +75,9 @@
  * @since 9
  */
 module java.base {
-    // source file: file:///scratch/mesos/slaves/e283bbd4-d3d7-4cc0-a152-4405cadfe7cb-S5239/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/e5d13b9d-8c0b-4873-9a0e-174587889864/runs/6c36c6b9-1366-4c8c-92f7-5f0a0b4af623/workspace/src/java.base/share/classes/module-info.java
-    //              file:///scratch/mesos/slaves/e283bbd4-d3d7-4cc0-a152-4405cadfe7cb-S5239/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/e5d13b9d-8c0b-4873-9a0e-174587889864/runs/6c36c6b9-1366-4c8c-92f7-5f0a0b4af623/workspace/src/java.base/macosx/classes/module-info.java.extra
-    //              file:///scratch/mesos/slaves/e283bbd4-d3d7-4cc0-a152-4405cadfe7cb-S5239/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/e5d13b9d-8c0b-4873-9a0e-174587889864/runs/6c36c6b9-1366-4c8c-92f7-5f0a0b4af623/workspace/src/java.base/unix/classes/module-info.java.extra
+    // source file: file:///scratch/mesos/slaves/83bb4d84-382c-4ead-b585-d8ef0018fefe-S19389/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/f5e15d85-8890-4c2b-ad8c-8fc384f02f88/runs/a8d3d456-34ef-4590-84f9-fe9e855ea603/workspace/open/src/java.base/share/classes/module-info.java
+    //              file:///scratch/mesos/slaves/83bb4d84-382c-4ead-b585-d8ef0018fefe-S19389/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/f5e15d85-8890-4c2b-ad8c-8fc384f02f88/runs/a8d3d456-34ef-4590-84f9-fe9e855ea603/workspace/open/src/java.base/macosx/classes/module-info.java.extra
+    //              file:///scratch/mesos/slaves/83bb4d84-382c-4ead-b585-d8ef0018fefe-S19389/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/f5e15d85-8890-4c2b-ad8c-8fc384f02f88/runs/a8d3d456-34ef-4590-84f9-fe9e855ea603/workspace/open/src/java.base/unix/classes/module-info.java.extra
     exports java.io;
     exports java.lang;
     exports java.lang.annotation;
@@ -130,6 +130,7 @@ module java.base {
     exports javax.security.auth.x500;
     exports javax.security.cert;
     exports com.sun.security.ntlm to java.security.sasl;
+    exports jdk.internal to jdk.jfr;
     exports jdk.internal.jimage to jdk.jlink;
     exports jdk.internal.jimage.decompressor to jdk.jlink;
     exports jdk.internal.jmod to
@@ -140,12 +141,12 @@ module java.base {
         java.instrument,
         java.logging;
     exports jdk.internal.logger to java.logging;
-    exports jdk.internal.math to java.desktop;
     exports jdk.internal.misc to
         java.desktop,
         java.logging,
         java.management,
         java.naming,
+        java.net.http,
         java.rmi,
         java.security.jgss,
         java.sql,
@@ -153,9 +154,8 @@ module java.base {
         jdk.attach,
         jdk.charsets,
         jdk.compiler,
-        jdk.incubator.httpclient,
         jdk.internal.vm.ci,
-        jdk.jdeps,
+        jdk.jfr,
         jdk.jlink,
         jdk.jshell,
         jdk.net,
@@ -166,18 +166,26 @@ module java.base {
         java.instrument,
         java.management.rmi,
         jdk.jartool,
+        jdk.jfr,
         jdk.jlink;
     exports jdk.internal.org.objectweb.asm to
-        jdk.internal.vm.ci,
         jdk.jartool,
+        jdk.jfr,
         jdk.jlink,
         jdk.scripting.nashorn;
-    exports jdk.internal.org.objectweb.asm.commons to jdk.scripting.nashorn;
+    exports jdk.internal.org.objectweb.asm.commons to
+        jdk.jfr,
+        jdk.scripting.nashorn;
     exports jdk.internal.org.objectweb.asm.signature to jdk.scripting.nashorn;
-    exports jdk.internal.org.objectweb.asm.tree to jdk.jlink;
-    exports jdk.internal.org.objectweb.asm.util to jdk.scripting.nashorn;
+    exports jdk.internal.org.objectweb.asm.tree to
+        jdk.jfr,
+        jdk.jlink;
+    exports jdk.internal.org.objectweb.asm.util to
+        jdk.jfr,
+        jdk.scripting.nashorn;
+    exports jdk.internal.org.xml.sax to jdk.jfr;
+    exports jdk.internal.org.xml.sax.helpers to jdk.jfr;
     exports jdk.internal.perf to
-        java.desktop,
         java.management,
         jdk.internal.jvmstat,
         jdk.management.agent;
@@ -192,15 +200,16 @@ module java.base {
         jdk.scripting.nashorn,
         jdk.unsupported;
     exports jdk.internal.util.jar to jdk.jartool;
+    exports jdk.internal.util.xml to jdk.jfr;
+    exports jdk.internal.util.xml.impl to jdk.jfr;
     exports jdk.internal.vm to
         jdk.internal.jvmstat,
         jdk.management.agent;
     exports jdk.internal.vm.annotation to
-        jdk.incubator.httpclient,
         jdk.internal.vm.ci,
         jdk.unsupported;
     exports sun.net to
-        jdk.incubator.httpclient,
+        java.net.http,
         jdk.naming.dns;
     exports sun.net.dns to
         java.security.jgss,
@@ -208,16 +217,17 @@ module java.base {
     exports sun.net.ext to jdk.net;
     exports sun.net.util to
         java.desktop,
-        jdk.incubator.httpclient,
+        java.net.http,
         jdk.jconsole;
     exports sun.net.www to
         java.desktop,
-        jdk.incubator.httpclient,
+        java.net.http,
         jdk.jartool;
     exports sun.net.www.protocol.http to java.security.jgss;
     exports sun.nio.ch to
         java.management,
         jdk.crypto.cryptoki,
+        jdk.net,
         jdk.sctp,
         jdk.unsupported;
     exports sun.nio.cs to
@@ -232,8 +242,7 @@ module java.base {
         java.management,
         java.management.rmi,
         java.rmi,
-        java.sql.rowset,
-        java.xml;
+        java.sql.rowset;
     exports sun.security.action to
         java.desktop,
         java.security.jgss;
@@ -270,13 +279,13 @@ module java.base {
         jdk.jartool,
         jdk.security.auth,
         jdk.security.jgss;
+    exports sun.security.util.math to jdk.crypto.ec;
+    exports sun.security.util.math.intpoly to jdk.crypto.ec;
     exports sun.security.validator to jdk.jartool;
     exports sun.security.x509 to
         jdk.crypto.cryptoki,
         jdk.crypto.ec,
-        jdk.jartool,
-        jdk.security.auth;
-    exports sun.text.resources to jdk.localedata;
+        jdk.jartool;
     exports sun.util.cldr to jdk.jlink;
     exports sun.util.locale.provider to
         java.desktop,
@@ -316,7 +325,6 @@ module java.base {
     uses java.util.spi.ToolProvider;
     uses javax.security.auth.spi.LoginModule;
     uses jdk.internal.logger.DefaultLoggerFinder;
-    uses sun.security.ssl.ClientKeyExchangeService;
     uses sun.text.spi.JavaTimeDateTimePatternProvider;
     uses sun.util.locale.provider.LocaleDataMetaInfo;
     uses sun.util.resources.LocaleData.CommonResourceBundleProvider;
