@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2016, 2018, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,23 +24,30 @@
  */
 
 module jdk.internal.vm.compiler {
-    // source file: file:///scratch/mesos/slaves/e283bbd4-d3d7-4cc0-a152-4405cadfe7cb-S5239/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/e5d13b9d-8c0b-4873-9a0e-174587889864/runs/6c36c6b9-1366-4c8c-92f7-5f0a0b4af623/workspace/src/jdk.internal.vm.compiler/share/classes/module-info.java
-    //              file:///scratch/mesos/slaves/e283bbd4-d3d7-4cc0-a152-4405cadfe7cb-S5239/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/e5d13b9d-8c0b-4873-9a0e-174587889864/runs/6c36c6b9-1366-4c8c-92f7-5f0a0b4af623/workspace/build/macosx-x64-open/support/gensrc/jdk.internal.vm.compiler/module-info.java.extra
+    // source file: file:///scratch/mesos/slaves/83bb4d84-382c-4ead-b585-d8ef0018fefe-S19389/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/f5e15d85-8890-4c2b-ad8c-8fc384f02f88/runs/a8d3d456-34ef-4590-84f9-fe9e855ea603/workspace/open/src/jdk.internal.vm.compiler/share/classes/module-info.java
+    //              file:///scratch/mesos/slaves/83bb4d84-382c-4ead-b585-d8ef0018fefe-S19389/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/f5e15d85-8890-4c2b-ad8c-8fc384f02f88/runs/a8d3d456-34ef-4590-84f9-fe9e855ea603/workspace/build/macosx-x64-open/support/gensrc/jdk.internal.vm.compiler/module-info.java.extra
     requires java.instrument;
     requires java.management;
     requires jdk.internal.vm.ci;
     requires jdk.management;
     requires jdk.unsupported;   // sun.misc.Unsafe is used
+    exports jdk.internal.vm.compiler.collections to jdk.internal.vm.compiler.management;
+    exports jdk.internal.vm.compiler.word to jdk.aot;
     exports org.graalvm.compiler.api.directives to jdk.aot;
     exports org.graalvm.compiler.api.replacements to jdk.aot;
     exports org.graalvm.compiler.api.runtime to jdk.aot;
+    exports org.graalvm.compiler.asm.aarch64 to jdk.aot;
     exports org.graalvm.compiler.asm.amd64 to jdk.aot;
     exports org.graalvm.compiler.bytecode to jdk.aot;
     exports org.graalvm.compiler.code to jdk.aot;
     exports org.graalvm.compiler.core to jdk.aot;
-    exports org.graalvm.compiler.core.common to jdk.aot;
+    exports org.graalvm.compiler.core.common to
+        jdk.aot,
+        jdk.internal.vm.compiler.management;
     exports org.graalvm.compiler.core.target to jdk.aot;
-    exports org.graalvm.compiler.debug to jdk.aot;
+    exports org.graalvm.compiler.debug to
+        jdk.aot,
+        jdk.internal.vm.compiler.management;
     exports org.graalvm.compiler.graph to jdk.aot;
     exports org.graalvm.compiler.hotspot to
         jdk.aot,
@@ -54,24 +61,30 @@ module jdk.internal.vm.compiler {
     exports org.graalvm.compiler.lir.phases to jdk.aot;
     exports org.graalvm.compiler.nodes to jdk.aot;
     exports org.graalvm.compiler.nodes.graphbuilderconf to jdk.aot;
-    exports org.graalvm.compiler.options to jdk.aot;
+    exports org.graalvm.compiler.options to
+        jdk.aot,
+        jdk.internal.vm.compiler.management;
     exports org.graalvm.compiler.phases to jdk.aot;
     exports org.graalvm.compiler.phases.tiers to jdk.aot;
     exports org.graalvm.compiler.printer to jdk.aot;
     exports org.graalvm.compiler.replacements to jdk.aot;
     exports org.graalvm.compiler.runtime to jdk.aot;
+    exports org.graalvm.compiler.serviceprovider to
+        jdk.aot,
+        jdk.internal.vm.compiler.management;
     exports org.graalvm.compiler.word to jdk.aot;
-    exports org.graalvm.word to jdk.aot;
 
     uses org.graalvm.compiler.code.DisassemblerProvider;
     uses org.graalvm.compiler.core.match.MatchStatementSet;
+    uses org.graalvm.compiler.debug.DebugHandlersFactory;
     uses org.graalvm.compiler.debug.TTYStreamProvider;
     uses org.graalvm.compiler.hotspot.CompilerConfigurationFactory;
     uses org.graalvm.compiler.hotspot.HotSpotBackendFactory;
     uses org.graalvm.compiler.hotspot.HotSpotCodeCacheListener;
+    uses org.graalvm.compiler.hotspot.HotSpotGraalManagementRegistration;
     uses org.graalvm.compiler.nodes.graphbuilderconf.NodeIntrinsicPluginFactory;
     uses org.graalvm.compiler.options.OptionDescriptors;
-    uses org.graalvm.compiler.options.OptionValuesAccess;
+    uses org.graalvm.compiler.serviceprovider.GraalServices.JMXService;
     provides jdk.vm.ci.services.JVMCIServiceLocator with org.graalvm.compiler.hotspot.HotSpotGraalJVMCIServiceLocator;
     provides org.graalvm.compiler.code.DisassemblerProvider with
         org.graalvm.compiler.code.HexCodeFileDisassemblerProvider,
@@ -82,7 +95,7 @@ module jdk.internal.vm.compiler {
     provides org.graalvm.compiler.debug.DebugHandlersFactory with org.graalvm.compiler.printer.GraalDebugHandlersFactory;
     provides org.graalvm.compiler.debug.TTYStreamProvider with org.graalvm.compiler.hotspot.HotSpotTTYStreamProvider;
     provides org.graalvm.compiler.hotspot.CompilerConfigurationFactory with
-        org.graalvm.compiler.hotspot.CoreCompilerConfigurationFactory,
+        org.graalvm.compiler.hotspot.CommunityCompilerConfigurationFactory,
         org.graalvm.compiler.hotspot.EconomyCompilerConfigurationFactory;
     provides org.graalvm.compiler.hotspot.HotSpotBackendFactory with
         org.graalvm.compiler.hotspot.aarch64.AArch64HotSpotBackendFactory,
@@ -126,6 +139,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.replacements.PluginFactory_IdentityHashCodeNode,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_MonitorSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_NewObjectSnippets,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_ObjectSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_StringToBytesSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ThreadSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_WriteBarrierSnippets,
@@ -164,12 +178,15 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.nodes.java.PluginFactory_RegisterFinalizerNode,
         org.graalvm.compiler.nodes.memory.PluginFactory_MemoryAnchorNode,
         org.graalvm.compiler.nodes.memory.address.PluginFactory_OffsetAddressNode,
+        org.graalvm.compiler.replacements.PluginFactory_ConstantStringIndexOfSnippets,
         org.graalvm.compiler.replacements.PluginFactory_Log,
         org.graalvm.compiler.replacements.PluginFactory_SnippetCounterNode,
         org.graalvm.compiler.replacements.aarch64.PluginFactory_AArch64FloatArithmeticSnippets,
         org.graalvm.compiler.replacements.aarch64.PluginFactory_AArch64IntegerArithmeticSnippets,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64MathSubstitutions,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringIndexOfNode,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringSubstitutions,
+        org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayCompareToNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayEqualsNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_AssertionNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_BinaryMathIntrinsicNode,
@@ -180,10 +197,11 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.replacements.nodes.PluginFactory_ExplodeLoopNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_UnaryMathIntrinsicNode;
     provides org.graalvm.compiler.options.OptionDescriptors with
+        org.graalvm.compiler.core.GraalCompilerOptions_OptionDescriptors,
+        org.graalvm.compiler.core.amd64.AMD64NodeLIRBuilder_OptionDescriptors,
         org.graalvm.compiler.core.common.GraalOptions_OptionDescriptors,
         org.graalvm.compiler.core.common.spi.JavaConstantFieldProvider_OptionDescriptors,
         org.graalvm.compiler.core.common.util.CompilationAlarm_OptionDescriptors,
-        org.graalvm.compiler.core.GraalCompilerOptions_OptionDescriptors,
         org.graalvm.compiler.core.phases.HighTier_OptionDescriptors,
         org.graalvm.compiler.core.phases.LowTier_OptionDescriptors,
         org.graalvm.compiler.debug.Assertions_OptionDescriptors,
@@ -194,29 +212,29 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.CompilationStatistics_OptionDescriptors,
         org.graalvm.compiler.hotspot.CompilationWatchDog_OptionDescriptors,
         org.graalvm.compiler.hotspot.CompilerConfigurationFactory_OptionDescriptors,
-        org.graalvm.compiler.hotspot.debug.BenchmarkCounters_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotBackend_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotGraalCompilerFactory_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotTTYStreamProvider_OptionDescriptors,
+        org.graalvm.compiler.hotspot.debug.BenchmarkCounters_OptionDescriptors,
         org.graalvm.compiler.hotspot.meta.HotSpotAOTProfilingPlugin_OptionDescriptors,
         org.graalvm.compiler.hotspot.meta.HotSpotProfilingPlugin_OptionDescriptors,
         org.graalvm.compiler.hotspot.nodes.profiling.ProfileNode_OptionDescriptors,
-        org.graalvm.compiler.hotspot.phases.aot.AOTInliningPolicy_OptionDescriptors,
         org.graalvm.compiler.hotspot.phases.OnStackReplacementPhase_OptionDescriptors,
+        org.graalvm.compiler.hotspot.phases.aot.AOTInliningPolicy_OptionDescriptors,
         org.graalvm.compiler.hotspot.phases.profiling.FinalizeProfileNodesPhase_OptionDescriptors,
         org.graalvm.compiler.hotspot.replacements.HotspotSnippetsOptions_OptionDescriptors,
         org.graalvm.compiler.hotspot.stubs.StubOptions_OptionDescriptors,
         org.graalvm.compiler.java.BytecodeParserOptions_OptionDescriptors,
-        org.graalvm.compiler.lir.alloc.lsra.LinearScan_OptionDescriptors,
+        org.graalvm.compiler.lir.BailoutAndRestartBackendException_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.lsra.LinearScanEliminateSpillMovePhase_OptionDescriptors,
+        org.graalvm.compiler.lir.alloc.lsra.LinearScan_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.lsra.OptimizingLinearScanWalker_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.trace.DefaultTraceRegisterAllocationPolicy_OptionDescriptors,
-        org.graalvm.compiler.lir.alloc.trace.lsra.TraceLinearScanPhase_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.trace.TraceBuilderPhase_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.trace.TraceRegisterAllocationPhase_OptionDescriptors,
+        org.graalvm.compiler.lir.alloc.trace.lsra.TraceLinearScanPhase_OptionDescriptors,
         org.graalvm.compiler.lir.amd64.phases.StackMoveOptimizationPhase_OptionDescriptors,
         org.graalvm.compiler.lir.asm.CompilationResultBuilder_OptionDescriptors,
-        org.graalvm.compiler.lir.BailoutAndRestartBackendException_OptionDescriptors,
         org.graalvm.compiler.lir.constopt.ConstantLoadOptimization_OptionDescriptors,
         org.graalvm.compiler.lir.gen.LIRGenerator_OptionDescriptors,
         org.graalvm.compiler.lir.phases.LIRPhase_OptionDescriptors,
@@ -227,10 +245,11 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.nodes.util.GraphUtil_OptionDescriptors,
         org.graalvm.compiler.phases.BasePhase_OptionDescriptors,
         org.graalvm.compiler.phases.common.DeadCodeEliminationPhase_OptionDescriptors,
+        org.graalvm.compiler.phases.common.NodeCounterPhase_OptionDescriptors,
+        org.graalvm.compiler.phases.common.UseTrappingNullChecksPhase_OptionDescriptors,
         org.graalvm.compiler.phases.common.inlining.InliningPhase_OptionDescriptors,
         org.graalvm.compiler.printer.NoDeadCodeVerifyHandler_OptionDescriptors,
         org.graalvm.compiler.replacements.PEGraphDecoder_OptionDescriptors,
         org.graalvm.compiler.replacements.SnippetTemplate_OptionDescriptors,
         org.graalvm.compiler.virtual.phases.ea.PartialEscapePhase_OptionDescriptors;
-    provides org.graalvm.compiler.options.OptionValuesAccess with org.graalvm.compiler.hotspot.HotSpotGraalOptionValues;
 }
